@@ -43,6 +43,11 @@ use crate::Error;
 use crate::Result;
 use crate::runtime::sync::Mutex;
 use std::ops::DerefMut;
+use uuid::Uuid;
+use crate::types::byte::RbBytes;
+use chrono::Utc;
+use bigdecimal_::BigDecimal;
+use serde_json::Value;
 
 #[derive(Debug, Clone)]
 pub struct DBPool {
@@ -581,7 +586,7 @@ pub struct DBQuery<'q> {
 
 
 impl<'q> DBQuery<'q> {
-    pub fn bind_value(&mut self, t: &serde_json::Value) -> crate::Result<()> {
+    pub fn bind_value(&mut self, t: serde_json::Value) -> crate::Result<()> {
         match &self.driver_type {
             &DriverType::None => {
                 return Err(Error::from("un init DBPool!"));
@@ -591,7 +596,7 @@ impl<'q> DBQuery<'q> {
                 let mut q = self.mysql.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
-                        q = q.bind(Some(s.to_owned()));
+                        q = q.bind(Some(s));
                     }
                     serde_json::Value::Null => {
                         q = q.bind(Option::<i32>::None);
@@ -608,6 +613,21 @@ impl<'q> DBQuery<'q> {
                     serde_json::Value::Bool(b) => {
                         q = q.bind(Option::Some(b.to_owned()));
                     }
+                    serde_json::Value::Array(arr) => {}
+                    serde_json::Value::Object(m) => {
+                        for (k, v) in m {
+                            match k.as_str() {
+                                "rb_bytes" => {
+                                    let bt = RbBytes::from(v);
+                                    q = q.bind(bt.rb_bytes);
+                                }
+                                _ => {
+                                    //json
+                                    q = q.bind(v);
+                                }
+                            }
+                        }
+                    }
                     _ => {
                         q = q.bind(Some(t.to_string()));
                     }
@@ -619,7 +639,7 @@ impl<'q> DBQuery<'q> {
                 let mut q = self.postgres.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
-                        q = q.bind(Some(s.to_owned()));
+                        q = q.bind(Some(s));
                     }
                     serde_json::Value::Null => {
                         q = q.bind(Option::<i32>::None);
@@ -636,6 +656,49 @@ impl<'q> DBQuery<'q> {
                     serde_json::Value::Bool(b) => {
                         q = q.bind(Option::Some(b.to_owned()));
                     }
+                    serde_json::Value::Array(arr) => {
+                        let mut rb_bytes = Vec::new();
+                        let mut rb_json = Vec::new();
+                        for x in arr {
+                            match x {
+                                Value::Object(x) => {
+                                    for (k, v) in x {
+                                        match k.as_str() {
+                                            "rb_bytes" => {
+                                                let bt = RbBytes::from(v);
+                                                rb_bytes.push(bt.rb_bytes);
+                                            }
+                                            _ => {
+                                                //json
+                                                rb_json.push(v);
+                                            }
+                                        }
+                                    }
+                                }
+                                _ => {}
+                            }
+                        }
+                        if !rb_bytes.is_empty() {
+                            q = q.bind(Some(rb_bytes));
+                        }
+                        if !rb_json.is_empty() {
+                            q = q.bind(Some(rb_json));
+                        }
+                    }
+                    serde_json::Value::Object(m) => {
+                        for (k, v) in m {
+                            match k.as_str() {
+                                "rb_bytes" => {
+                                    let bt = RbBytes::from(v);
+                                    q = q.bind(bt.rb_bytes);
+                                }
+                                _ => {
+                                    //json
+                                    q = q.bind(v);
+                                }
+                            }
+                        }
+                    }
                     _ => {
                         q = q.bind(Some(t.to_string()));
                     }
@@ -647,7 +710,7 @@ impl<'q> DBQuery<'q> {
                 let mut q = self.sqlite.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
-                        q = q.bind(Some(s.to_owned()));
+                        q = q.bind(Some(s));
                     }
                     serde_json::Value::Null => {
                         q = q.bind(Option::<i32>::None);
@@ -664,6 +727,20 @@ impl<'q> DBQuery<'q> {
                     serde_json::Value::Bool(b) => {
                         q = q.bind(Option::Some(b.to_owned()));
                     }
+                    serde_json::Value::Object(m) => {
+                        for (k, v) in m {
+                            match k.as_str() {
+                                "rb_bytes" => {
+                                    let bt = RbBytes::from(v);
+                                    q = q.bind(bt.rb_bytes);
+                                }
+                                _ => {
+                                    //json
+                                    q = q.bind(v);
+                                }
+                            }
+                        }
+                    }
                     _ => {
                         q = q.bind(Some(t.to_string()));
                     }
@@ -675,7 +752,7 @@ impl<'q> DBQuery<'q> {
                 let mut q = self.mssql.take().ok_or_else(|| Error::from("[rbatis-core] conn is none!"))?;
                 match t {
                     serde_json::Value::String(s) => {
-                        q = q.bind(Some(s.to_owned()));
+                        q = q.bind(Some(s));
                     }
                     serde_json::Value::Null => {
                         q = q.bind(Option::<i32>::None);
@@ -692,6 +769,16 @@ impl<'q> DBQuery<'q> {
                     serde_json::Value::Bool(b) => {
                         q = q.bind(Option::Some(b.to_owned()));
                     }
+                    serde_json::Value::Object(m) => {
+                        for (k, v) in m {
+                            match k.as_str() {
+                                "rb_bytes" => {
+                                    return crate::Result::Err(crate::Error::from("unsupport type!"));
+                                }
+                                _ => {}
+                            }
+                        }
+                    }
                     _ => {
                         q = q.bind(Some(t.to_string()));
                     }
