@@ -9,7 +9,7 @@ use sqlx_core::types::{BigDecimal, Json};
 use sqlx_core::value::ValueRef;
 
 use crate::convert::{JsonCodec, RefJsonCodec, ResultCodec};
-use chrono::{DateTime, Utc};
+use chrono::{DateTime, Utc, NaiveDate};
 
 use crate::{new_json_option_into};
 
@@ -22,7 +22,10 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
             }
             "DECIMAL" => {
                 let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
-                return Ok(new_json_option_into!(r));
+                if let Some(date) = r {
+                    return Ok(serde_json::Value::String(date));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "BIGINT UNSIGNED" => {
                 let r: Option<u64> = Decode::<'_, MySql>::decode(self)?;
@@ -71,7 +74,12 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
             "BLOB" | "TINYBLOB" | "MEDIUMBLOB" | "LONGBLOB" | "TINYTEXT" | "MEDIUMTEXT"
             | "LONGTEXT" => {
                 let r: Option<Vec<u8>> = Decode::<'_, MySql>::decode(self)?;
-                return Ok(new_json_option_into!(r));
+                if let Some(r) = r {
+                    return Ok(serde_json::json!(crate::types::byte::RbBytes{
+                        rb_bytes:r,
+                    }));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "BIT" | "BOOLEAN" => {
                 let r: Option<u8> = Decode::<'_, MySql>::decode(self)?;
@@ -79,24 +87,39 @@ impl<'r> JsonCodec for sqlx_core::mysql::MySqlValueRef<'r> {
             }
 
             "DATE" => {
-                let r: Option<chrono::NaiveDate> = Decode::<'_, MySql>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
+                if let Some(date) = r {
+                    return Ok(serde_json::Value::String(date));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIME" | "YEAR" => {
-                let r: Option<chrono::NaiveTime> = Decode::<'_, MySql>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
+                if let Some(date) = r {
+                    return Ok(serde_json::Value::String(date));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "DATETIME" => {
-                let r: Option<chrono::NaiveDateTime> = Decode::<'_, MySql>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
+                if let Some(date) = r {
+                    return Ok(serde_json::Value::String(date));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIMESTAMP" => {
-                let r: Option<chrono::NaiveDateTime> = Decode::<'_, MySql>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, MySql>::decode(self)?;
+                if let Some(date) = r {
+                    return Ok(serde_json::Value::String(date));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "JSON" => {
                 let r: Option<Json<serde_json::Value>> = Decode::<'_, MySql>::decode(self)?;
-                return Ok(json!(r));
+                if let Some(r) = r {
+                    return Ok(r.0);
+                }
+                return Ok(serde_json::Value::Null);
             }
             _ => {
                 //TODO "GEOMETRY" support. for now you can use already supported types to decode this
