@@ -18,6 +18,7 @@ use crate::postgres::PgInterval;
 use chrono::Utc;
 
 use crate::{new_json_option_into};
+use std::option::Option::Some;
 
 impl<'c> JsonCodec for PgValueRef<'c> {
     fn try_to_json(self) -> crate::Result<serde_json::Value> {
@@ -28,12 +29,18 @@ impl<'c> JsonCodec for PgValueRef<'c> {
             "NUMERIC" => {
                 //decimal
                 let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(new_json_option_into!(r));
+                if let Some(date) = r {
+                    return Ok(serde_json::Value::String(date));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "NUMERIC[]" => {
                 //decimal
                 let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(new_json_option_into!(r));
+                if let Some(r) = r {
+                    return Ok(serde_json::Value::from(r));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "MONEY" => {
                 //decimal
@@ -55,7 +62,12 @@ impl<'c> JsonCodec for PgValueRef<'c> {
             }
             "BYTEA" | "BYTEA[]" => {
                 let r: Option<Vec<u8>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(new_json_option_into!(r));
+                if let Some(r) = r {
+                    return Ok(serde_json::json!(crate::types::byte::RbBytes{
+                        rb_bytes:r,
+                    }));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "FLOAT4" => {
                 let r: Option<f32> = Decode::<'_, Postgres>::decode(self)?;
@@ -115,52 +127,92 @@ impl<'c> JsonCodec for PgValueRef<'c> {
                 return Ok(new_json_option_into!(r));
             }
             "UUID" => {
-                let r: Option<Uuid> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(r) = r {
+                    return Ok(serde_json::Value::String(r));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "UUID[]" => {
-                let r: Option<Vec<Uuid>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(r) = r {
+                    return Ok(serde_json::Value::from(r));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "JSON" | "JSONB" => {
                 let r: Option<Json<serde_json::Value>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                if let Some(r) = r {
+                    return Ok(r.0);
+                }
+                return Ok(serde_json::Value::Null);
             }
             "JSON[]" | "JSONB[]" => {
                 let r: Option<Vec<Json<serde_json::Value>>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                if let Some(r) = r {
+                    let mut arr = Vec::with_capacity(r.capacity());
+                    for x in r {
+                        arr.push(x.0);
+                    }
+                    return Ok(serde_json::Value::Array(arr));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIME" => {
-                let r: Option<Time> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(date) = r {
+                    return Ok(serde_json::Value::String(date));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIME[]" => {
-                let r: Option<Vec<Time>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dates) = r {
+                    return Ok(serde_json::Value::from(dates));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "DATE" => {
-                let r: Option<chrono::NaiveDate> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dates) = r {
+                    return Ok(serde_json::Value::from(dates));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "DATE[]" => {
-                let r: Option<Vec<chrono::NaiveDate>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dates) = r {
+                    return Ok(serde_json::Value::from(dates));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIMESTAMP" => {
-                let r: Option<chrono::NaiveDateTime> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dates) = r {
+                    return Ok(serde_json::Value::from(dates));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIMESTAMP[]" => {
-                let r: Option<Vec<chrono::NaiveDateTime>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dates) = r {
+                    return Ok(serde_json::Value::from(dates));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIMESTAMPTZ" => {
-                let r: Option<chrono::DateTime<Utc>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<String> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dates) = r {
+                    return Ok(serde_json::Value::from(dates));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "TIMESTAMPTZ[]" => {
-                let r: Option<Vec<chrono::DateTime<Utc>>> = Decode::<'_, Postgres>::decode(self)?;
-                return Ok(json!(r));
+                let r: Option<Vec<String>> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dates) = r {
+                    return Ok(serde_json::Value::from(dates));
+                }
+                return Ok(serde_json::Value::Null);
             }
             "CIDR" | "INET" => {
                 let r: Option<IpNetwork> = Decode::<'_, Postgres>::decode(self)?;
